@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2013 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2016 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_BINARY_H
@@ -12,7 +12,7 @@
  * Config
  */
 
-#define SIEVE_BINARY_VERSION_MAJOR     0
+#define SIEVE_BINARY_VERSION_MAJOR     1
 #define SIEVE_BINARY_VERSION_MINOR     4
 
 /*
@@ -111,9 +111,12 @@ unsigned int sieve_binary_block_get_id
 struct sieve_binary_extension {
 	const struct sieve_extension_def *extension;
 
-	bool (*binary_save)
+	bool (*binary_pre_save)
 		(const struct sieve_extension *ext, struct sieve_binary *sbin,
-			void *context);
+			void *context, enum sieve_error *error_r);
+	bool (*binary_post_save)
+		(const struct sieve_extension *ext, struct sieve_binary *sbin,
+			void *context, enum sieve_error *error_r);
 	bool (*binary_open)
 		(const struct sieve_extension *ext, struct sieve_binary *sbin,
 			void *context);
@@ -203,30 +206,31 @@ void sieve_binary_emit_extension_object
 
 bool sieve_binary_read_byte
 	(struct sieve_binary_block *sblock, sieve_size_t *address,
-		unsigned int *byte_r);
+		unsigned int *byte_r) ATTR_NULL(3);
 bool sieve_binary_read_code
 	(struct sieve_binary_block *sblock, sieve_size_t *address,
-		signed int *code_r);
+		signed int *code_r) ATTR_NULL(3);
 bool sieve_binary_read_offset
 	(struct sieve_binary_block *sblock, sieve_size_t *address,
-		sieve_offset_t *offset_r);
+		sieve_offset_t *offset_r) ATTR_NULL(3);
 bool sieve_binary_read_integer
   (struct sieve_binary_block *sblock, sieve_size_t *address,
-		sieve_number_t *int_r);
+		sieve_number_t *int_r) ATTR_NULL(3);
 bool sieve_binary_read_string
   (struct sieve_binary_block *sblock, sieve_size_t *address,
-		string_t **str_r);
+		string_t **str_r) ATTR_NULL(3);
 
 static inline bool sieve_binary_read_unsigned
 (struct sieve_binary_block *sblock, sieve_size_t *address,
-	unsigned int *count_r)
+	unsigned int *count_r) ATTR_NULL(3)
 {
-	sieve_number_t integer;
+	sieve_number_t integer = 0;
 
 	if ( !sieve_binary_read_integer(sblock, address, &integer) )
 		return FALSE;
 
-	*count_r = integer;
+	if ( count_r != NULL )
+		*count_r = integer;
 
 	return TRUE;
 }
