@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2016 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_SETTINGS_H
@@ -7,7 +7,7 @@
 #include "sieve-common.h"
 
 /*
- * Settings
+ * Access to settings
  */
 
 static inline const char *sieve_setting_get
@@ -37,6 +37,13 @@ bool sieve_setting_get_duration_value
 	(struct sieve_instance *svinst, const char *setting,
 		sieve_number_t *value_r);
 
+/*
+ * Main Sieve engine settings
+ */
+
+void sieve_settings_load
+	(struct sieve_instance *svinst);
+
 /*
  * Home directory
  */
